@@ -2,7 +2,7 @@
 from SciDataTool.Functions import AxisError
 
 
-def get_length(self, is_oneperiod=False, is_antiperiod=False):
+def get_length(self, is_oneperiod=False, is_antiperiod=False, is_smallestperiod=False):
     """Returns the length of the axis taking symmetries into account.
     Parameters
     ----------
@@ -18,7 +18,9 @@ def get_length(self, is_oneperiod=False, is_antiperiod=False):
     """
     N = len(self.values)
     # Rebuild symmetries
-    if is_antiperiod:
+    if is_smallestperiod:
+        return N
+    elif is_antiperiod:
         if "antiperiod" in self.symmetries:
             return N
         else:
